@@ -460,7 +460,7 @@ Caveats
 Static method objects are *only* directly accessible via the low-level
 :attr:`object.__dict__` dictionary. When accessed as class or instance
 attributes, static methods reduce to instances of the standard
-:class:`FunctionType` type.
+:class:`.FunctionType` type.
 
 Static method objects are *not* callable, as their implementations fail to
 define the ``__call__`` dunder method.
@@ -1038,7 +1038,7 @@ else:
 
     * :func:`beartype._util.hint.pep.proposal.pep484.pep484.is_hint_pep484_generic`,
       detecting :pep:`484`-compliant generic type hints.
-    * :func:`beartype._util.hint.pep.proposal.pep585.is_hint_pep585_builtin_subscripted`,
+    * :func:`beartype._util.hint.pep.proposal.pep585.is_hint_pep585_builtin_subbed`,
       detecting :pep:`585`-compliant builtin type hints.
     * :func:`beartype._util.hint.pep.proposal.pep585.is_hint_pep585_generic`,
       detecting :pep:`585`-compliant generic type hints.
