@@ -14,7 +14,6 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.typing import (
-    Any,
     Callable,
     Optional,
 )
@@ -29,16 +28,15 @@ from beartype._check.checkmagic import (
     CODE_PITH_ROOT_NAME_PLACEHOLDER,
     FUNC_CHECKER_NAME_PREFIX,
 )
-from beartype._check.convert.convsanify import (
-    sanify_hint_root_statement)
+from beartype._check.convert.convsanify import sanify_hint_root_statement
 from beartype._check.code.codemake import make_check_expr
-from beartype._check.error.errget import (
+from beartype._check.error.errmain import (
     get_func_pith_violation,
     get_hint_object_violation,
 )
-from beartype._check.metadata.metasane import (
-    HintOrSanifiedData,
-    # get_hint_or_sane_hint,
+from beartype._check.metadata.hint.hintsane import (
+    HINT_SANE_IGNORABLE,
+    HintSane,
 )
 from beartype._check.signature.sigmake import make_func_signature
 from beartype._check._checksnip import (
@@ -52,7 +50,7 @@ from beartype._check._checksnip import (
     CODE_RAISE_VIOLATION,
     CODE_WARN_VIOLATION,
 )
-from beartype._conf.confcls import BeartypeConf
+from beartype._conf.confmain import BeartypeConf
 from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
 from beartype._conf.conftest import die_unless_conf
 from beartype._data.error.dataerrmagic import EXCEPTION_PLACEHOLDER
@@ -197,7 +195,7 @@ def make_func_tester(
 #FIXME: Unit test us up, please.
 @callable_cached
 def make_code_raiser_hint_object_check(
-    hint_or_sane: HintOrSanifiedData,
+    hint_sane: HintSane,
     hint_insane: Hint,
     conf: BeartypeConf,
     exception_prefix: str,
@@ -215,17 +213,15 @@ def make_code_raiser_hint_object_check(
 
     Parameters
     ----------
-    hint_or_sane : HintOrSanifiedData
-        Either a type hint *or* **sanified type hint metadata** (i.e.,
-        :data:`.HintSanifiedData` object) to be type-checked.
+    hint_sane : HintSane
+        Metadata encapsulating the type hint to be type-checked.
     hint_insane : Hint
         **Insane** (i.e., pre-sanified) type hint to be type-checked.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
     exception_prefix : str
-        Human-readable label prefixing the representation of this object in the
-        exception message.
+        Human-readable substring prefixing raised exception messages.
 
     Returns
     -------
@@ -250,7 +246,7 @@ def make_code_raiser_hint_object_check(
         code_expr,
         func_scope,
         hint_refs_type_basename,
-    ) = make_check_expr(hint_or_sane, conf)
+    ) = make_check_expr(hint_sane, conf)
 
     # Code snippet passing the value of the random integer previously generated
     # for the current call to the exception-handling function call embedded in
@@ -274,6 +270,7 @@ def make_code_raiser_hint_object_check(
     func_scope[ARG_NAME_GET_VIOLATION] = get_hint_object_violation
     func_scope[ARG_NAME_HINT] = hint_insane
 
+    #FIXME: [SPEED] Globalize this bound method as a negligible efficiency gain.
     # Code snippet generating a human-readable violation exception or warning
     # when the root pith violates the root type hint.
     code_get_violation = CODE_GET_HINT_OBJECT_VIOLATION.format(
@@ -304,7 +301,7 @@ def make_code_raiser_hint_object_check(
 #FIXME: Unit test us up, please.
 @callable_cached
 def make_code_tester_check(
-    hint_or_sane: HintOrSanifiedData,
+    hint_sane: HintSane,
     hint_insane: Hint,
     conf: BeartypeConf,
     exception_prefix : str,
@@ -321,9 +318,8 @@ def make_code_tester_check(
 
     Parameters
     ----------
-    hint_or_sane : HintOrSanifiedData
-        Either a type hint *or* **sanified type hint metadata** (i.e.,
-        :data:`.HintSanifiedData` object) to be type-checked.
+    hint_sane : HintSane
+        Metadata encapsulating the type hint to be type-checked.
     hint_insane : Hint
         **Insane** (i.e., pre-sanified) type hint to be type-checked. Although
         this factory ignores this hint, alternate factories require this hint.
@@ -331,8 +327,7 @@ def make_code_tester_check(
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
     exception_prefix : str
-        Human-readable label prefixing the representation of this object in the
-        exception message.
+        Human-readable substring prefixing raised exception messages.
 
     Returns
     -------
@@ -353,7 +348,7 @@ def make_code_tester_check(
         code_expr,
         func_scope,
         hint_refs_type_basename,
-    ) = make_check_expr(hint_or_sane, conf)
+    ) = make_check_expr(hint_sane, conf)
 
     # Code snippet type-checking the root pith against the root hint.
     func_code = f'{CODE_TESTER_CHECK_PREFIX}{code_expr}'
@@ -369,7 +364,7 @@ def make_code_tester_check(
 #FIXME: Unit test us up, please.
 @callable_cached
 def make_code_raiser_func_pith_check(
-    hint_or_sane: HintOrSanifiedData,
+    hint_sane: HintSane,
     conf: BeartypeConf,
     cls_stack: Optional[TypeStack],
     is_param: Optional[bool],
@@ -385,9 +380,8 @@ def make_code_raiser_func_pith_check(
 
     Parameters
     ----------
-    hint_or_sane : HintOrSanifiedData
-        Either a sanified type hint *or* **sanified type hint metadata** (i.e.,
-        :data:`.HintSanifiedData` object) to be type-checked.
+    hint_sane : HintSane
+        Metadata encapsulating the type hint to be type-checked.
     hint_insane : Hint
         **Insane** (i.e., pre-sanified) type hint to be type-checked.
     conf : BeartypeConf
@@ -437,7 +431,7 @@ def make_code_raiser_func_pith_check(
         code_expr,
         func_scope,
         hint_refs_type_basename,
-    ) = make_check_expr(hint_or_sane, conf, cls_stack)
+    ) = make_check_expr(hint_sane, conf, cls_stack)
 
     # Code snippet passing the value of the random integer previously generated
     # for the current call to the exception-handling function call embedded in
@@ -578,8 +572,8 @@ def _make_func_checker(
 ) -> CallableRaiserOrTester:
     '''
     **Type-checking function factory** (i.e., low-level callable dynamically
-    generating a pure-Python tester function testing whether an arbitrary object
-    passed to that tester satisfies the type hint passed to this factory and
+    generating a pure-Python function detecting whether an arbitrary object
+    passed to that function satisfies the type hint passed to this factory and
     either returning that result as its boolean return *or* raising a fatal
     exception or emitting a non-fatal warning if that result is :data:`False`).
 
@@ -605,8 +599,8 @@ def _make_func_checker(
         code snippet of a function type-checking an arbitrary object against the
         passed type hint under the passed beartype configuration).
     exception_prefix : str, optional
-        Human-readable label prefixing the representation of this object in the
-        exception message. Defaults to a reasonably sensible string.
+        Human-readable substring prefixing raised exception messages. Defaults
+        to a reasonably sensible string.
 
     Returns
     -------
@@ -656,13 +650,14 @@ def _make_func_checker(
             # unsupported by @beartype, raise an exception.
             #
             # Do this first *BEFORE* passing this hint to any further callables.
-            hint_or_sane = sanify_hint_root_statement(
+            hint_sane = sanify_hint_root_statement(
                 hint=hint, conf=conf, exception_prefix=EXCEPTION_PLACEHOLDER)
-            # print(f'Reduced tester root hint {repr(hint)} to hint or metadata {repr(hint_or_sane)}.')
+            # print(f'Reduced tester root hint {repr(hint)} to hint or metadata {repr(hint_sane)}.')
 
             # If this hint is ignorable, all objects satisfy this hint. In this
             # case, return a trivial function unconditionally returning true.
-            if hint_or_sane is Any:
+            if hint_sane is HINT_SANE_IGNORABLE:
+                # print(f'[_make_func_checker] Ignoring ignorable hint {hint} with conf {conf}!')
                 return _func_checker_ignorable
             # Else, this hint is unignorable.
 
@@ -673,7 +668,7 @@ def _make_func_checker(
                 code_check,
                 func_scope,
                 hint_refs_type_basename,
-            ) = make_code_check(hint_or_sane, hint, conf, exception_prefix)
+            ) = make_code_check(hint_sane, hint, conf, exception_prefix)
             # print(f'func_scope: {func_scope}')
 
             #FIXME: Actually, nothing below is particularly significant. Users
@@ -778,6 +773,7 @@ def _make_func_checker(
 
             # ....................{ FUNCTION               }....................
             # Type-checking tester function to be returned.
+            # print(f'Making checker {repr(func_checker_name)} with conf {conf}...')
             func_tester = make_func(
                 func_name=func_checker_name,
                 func_code=func_checker_code,
