@@ -14,6 +14,7 @@ This private submodule is *not* intended for importation by downstream callers.
 from beartype.typing import (
     Callable,
     Dict,
+    Optional,
 )
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._check.error.errcause import ViolationCause
@@ -21,7 +22,7 @@ from beartype._check.error.errcause import ViolationCause
 # ....................{ GLOBALS                            }....................
 # Initialized with automated inspection below in the _init() function.
 HINT_SIGN_TO_GET_CAUSE_FUNC: Dict[
-    HintSign, Callable[[ViolationCause], ViolationCause]] = {}
+    Optional[HintSign], Callable[[ViolationCause], ViolationCause]] = {}
 '''
 Dictionary mapping each **sign** (i.e., arbitrary object uniquely identifying a
 category of type hints) to a private getter function defined by this submodule
@@ -36,6 +37,7 @@ def _init() -> None:
     Initialize this submodule.
     '''
 
+    # ....................{ IMPORTS                        }....................
     # Defer heavyweight imports.
     from beartype._data.hint.pep.sign.datapepsigns import (
         HintSignAnnotated,
@@ -52,9 +54,9 @@ def _init() -> None:
         HINT_SIGNS_CONTAINER_ARGS_1,
         HINT_SIGNS_UNION,
     )
-    from beartype._check.error._errtype import (
+    from beartype._check.error._nonpep.errnonpeptype import (
         find_cause_instance_type_forwardref,
-        find_cause_subclass_type,
+        find_cause_nonpep,
         find_cause_type_instance_origin,
     )
     from beartype._check.error._pep.errpep484604 import (
@@ -64,14 +66,17 @@ def _init() -> None:
     from beartype._check.error._pep.pep484.errpep484noreturn import (
         find_cause_pep484_noreturn)
     from beartype._check.error._pep.pep484585.errpep484585container import (
-        find_cause_container_args_1,
-        find_cause_tuple_fixed,
+        find_cause_pep484585_container_args_1,
+        find_cause_pep484585_tuple_fixed,
     )
     from beartype._check.error._pep.pep484585.errpep484585generic import (
-        find_cause_generic_unsubscripted)
+        find_cause_pep484585_generic_unsubbed)
     from beartype._check.error._pep.pep484585.errpep484585mapping import (
-        find_cause_mapping)
+        find_cause_pep484585_mapping)
+    from beartype._check.error._pep.pep484585.errpep484585subclass import (
+        find_cause_pep484585_subclass)
 
+    # ....................{ FALLBACKS                      }....................
     # Map each originative sign to the appropriate finder *BEFORE* any other
     # mappings. This is merely a generalized fallback subsequently replaced by
     # sign-specific finders below.
@@ -80,27 +85,42 @@ def _init() -> None:
 
     # Map each 1-argument container sign to its corresponding finder.
     for hint_sign in HINT_SIGNS_CONTAINER_ARGS_1:
-        HINT_SIGN_TO_GET_CAUSE_FUNC[hint_sign] = find_cause_container_args_1
+        HINT_SIGN_TO_GET_CAUSE_FUNC[hint_sign] = (
+            find_cause_pep484585_container_args_1)
 
     # Map each 2-argument mapping sign to its corresponding finder.
     for hint_sign in HINT_SIGNS_MAPPING:
-        HINT_SIGN_TO_GET_CAUSE_FUNC[hint_sign] = find_cause_mapping
+        HINT_SIGN_TO_GET_CAUSE_FUNC[hint_sign] = find_cause_pep484585_mapping
 
     # Map each union-specific sign to its corresponding finder.
     for hint_sign in HINT_SIGNS_UNION:
         HINT_SIGN_TO_GET_CAUSE_FUNC[hint_sign] = find_cause_pep484604_union
 
+    # ....................{ SPECIFICS                      }....................
     # Map each sign validated by a unique finder to that finder *AFTER* all
     # other mappings. These sign-specific finders are intended to replace all
     # other automated mappings above.
     HINT_SIGN_TO_GET_CAUSE_FUNC.update({
-        HintSignAnnotated: find_cause_pep593_annotated,
+        # ....................{ NON-PEP                    }....................
+        # Map PEP-noncompliant hints identified by *NO* PEP-compliant signs to
+        # the catch-all PEP-noncompliant cause finder.
+        None: find_cause_nonpep,
+
+        # ....................{ PEP 484                    }....................
         HintSignForwardRef: find_cause_instance_type_forwardref,
-        HintSignPep484585GenericUnsubscripted: find_cause_generic_unsubscripted,
-        HintSignLiteral: find_cause_pep586_literal,
         HintSignNoReturn: find_cause_pep484_noreturn,
-        HintSignTupleFixed: find_cause_tuple_fixed,
-        HintSignType: find_cause_subclass_type,
+
+        # ....................{ PEP (484|585)              }....................
+        HintSignPep484585GenericUnsubscripted: (
+            find_cause_pep484585_generic_unsubbed),
+        HintSignTupleFixed: find_cause_pep484585_tuple_fixed,
+        HintSignType: find_cause_pep484585_subclass,
+
+        # ....................{ PEP 586                    }....................
+        HintSignLiteral: find_cause_pep586_literal,
+
+        # ....................{ PEP 593                    }....................
+        HintSignAnnotated: find_cause_pep593_annotated,
     })
 
 
