@@ -13,10 +13,13 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ TODO                               }....................
-#FIXME: The "ViolationCause.hint_childs" tuple is arguably useless. It's only
-#used in one other submodule and can, in any case, be trivially reconstructed
-#from the more useful "ViolationCause.hint_or_sane_childs" tuple. In other
-#words, please excise "ViolationCause.hint_childs".
+#FIXME: The following "ViolationCause" instance variables are trivial aliases
+#and thus useless. They should be excised where time permits; so, never:
+#* "ViolationCause.hint" is just an alias for "ViolationCause.hint_sane.hint".
+#* The "ViolationCause.hint_childs" tuple is only used in one other submodule
+#  and can, in any case, be trivially reconstructed from the more useful
+#  "ViolationCause.hint_childs_sane" tuple. In other words, please excise
+#  "ViolationCause.hint_childs".
 
 #FIXME: The recursive "ViolationCause" class strongly overlaps with the equally
 #recursive (and substantially superior) "beartype.door.TypeHint" class. Ideally:
@@ -29,7 +32,7 @@ This private submodule is *not* intended for importation by downstream callers.
 #  dataclass encapsulating metadata describing the current type-checking
 #  violation. That metadata (e.g., "cause_indent") is inappropriate for
 #  general-purpose type hints. Exceptions include:
-#  * "hint", "hint_sign", and "hint_or_sane_childs" -- all of which are subsumed
+#  * "hint", "hint_sign", and "hint_childs_sane" -- all of which are subsumed
 #    by the "TypeHint" dataclass and should thus be excised.
 #* Refactor the TypeHint._find_cause() method to accept an instance of
 #  the "_TypeHintUnbearability" dataclass: e.g.,
@@ -56,39 +59,32 @@ from beartype.typing import (
     Any,
     Callable,
     Optional,
-    Union,
 )
 from beartype._cave._cavemap import NoneTypeOr
 from beartype._check.convert.convsanify import sanify_hint_child
-from beartype._check.metadata.metasane import (
-    HintOrSanifiedData,
-    TupleHintOrSanifiedData,
-    get_hint_or_sane_hint,
-    unpack_hint_or_sane,
+from beartype._check.metadata.hint.hintsane import (
+    HINT_SANE_IGNORABLE,
+    HintSane,
+    TupleHintSane,
 )
-from beartype._conf.confcls import BeartypeConf
+from beartype._conf.confmain import BeartypeConf
 from beartype._data.hint.datahintpep import (
     Hint,
     TupleHints,
-    TypeVarToHint,
 )
-from beartype._data.hint.datahinttyping import TypeStack
-from beartype._data.kind.datakindmap import FROZENDICT_EMPTY
+from beartype._data.hint.datahinttyping import (
+    HintSignOrNoneOrSentinel,
+    TypeStack,
+)
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_SUPPORTED_DEEP,
     HINT_SIGNS_ORIGIN_ISINSTANCEABLE,
 )
-from beartype._util.hint.pep.utilpepget import (
-    get_hint_pep_args,
-    get_hint_pep_sign_or_none,
-)
+from beartype._data.kind.datakindiota import SENTINEL
+from beartype._util.hint.pep.utilpepget import get_hint_pep_args
+from beartype._util.hint.pep.utilpepsign import get_hint_pep_sign_or_none
 from beartype._util.hint.pep.utilpeptest import is_hint_pep
-from beartype._util.kind.map.utilmapfrozen import FrozenDict
-from beartype._util.utilobject import (
-    SENTINEL,
-    Iota,
-)
 from beartype._util.utilobjmake import permute_object
 
 # ....................{ CLASSES                            }....................
@@ -139,25 +135,28 @@ class ViolationCause(object):
         * Else, :data:`None`.
 
         This instance variable is effectively a streamlined variant of the
-        :attr:`hint_or_sane_childs` instance variable. Whereas the latter
+        :attr:`hint_childs_sane` instance variable. Whereas the latter
         *includes* all supplementary metadata, the former instance variable
         *excludes* all supplementary metadata and thus only contains hints.
-    hint_or_sane_childs : Optional[TupleHintOrSanifiedData]
+    hint_childs_sane : Optional[TupleHintSane]
         Either:
 
         * If this hint is PEP-compliant, the possibly empty tuple of all child
           hints subscripting (indexing) this hint such that each item is either:
 
           * If sanifying this child hint generated supplementary metadata, that
-            metadata (i.e., a :class:`.HintSanifiedData` object).
+            metadata (i.e., a :class:`.HintSane` object).
           * Else, this child hint as is.
 
         * Else, :data:`None`.
+    hint_sane : HintSane
+        Metadata encapsulating the sanification (i.e., sanitization) of the type
+        hint to validate this object against.
     hint_sign : Optional[HintSign]
         Either:
 
         * If this hint is PEP-compliant, the sign identifying this hint.
-        * Else, :data:`None` otherwise.
+        * Else, :data:`None`.
     pith : Any
         Arbitrary object to be validated.
     pith_name : Optional[str]
@@ -175,15 +174,7 @@ class ViolationCause(object):
         the current call to that function) if that function generated such an
         integer *or* ``None`` otherwise (i.e., if that function generated *no*
         such integer). See the same parameter accepted by the higher-level
-        :func:`beartype._check.error.errget.get_func_pith_violation` function.
-    typevar_to_hint : TypeVarToHint
-        **Type variable lookup table** (i.e., immutable dictionary mapping from
-        each :pep:`484`-compliant type variable parametrizing either the
-        currently visited type hint *or* a transitive parent type hint of this
-        hint to the corresponding non-type variable type hint subscripting that
-        hint). See also the comparable
-        :func:`beartype._check.codecls.HintMeta.typevar_to_hint` instance
-        variable.
+        :func:`beartype._check.error.errmain.get_func_pith_violation` function.
     '''
 
     # ..................{ CLASS VARIABLES                    }..................
@@ -199,12 +190,12 @@ class ViolationCause(object):
         'func',
         'hint',
         'hint_childs',
-        'hint_or_sane_childs',
+        'hint_childs_sane',
+        'hint_sane',
         'hint_sign',
         'pith',
         'pith_name',
         'random_int',
-        'typevar_to_hint',
     )
 
 
@@ -219,42 +210,54 @@ class ViolationCause(object):
         func: Optional[Callable]
         hint: Hint
         hint_childs: TupleHints
-        hint_or_sane_childs: TupleHintOrSanifiedData
+        hint_childs_sane: TupleHintSane
+        hint_sane: HintSane
         hint_sign: Optional[HintSign]
         pith: Any
         pith_name: Optional[str]
         random_int: Optional[int]
-        typevar_to_hint: TypeVarToHint
 
-
-    _INIT_PARAM_NAMES = frozenset((
+    # ..................{ CLASS VARIABLES ~ set              }..................
+    _COPY_VAR_NAMES = frozenset((
         'cause_indent',
-        'cause_str_or_none',
         'cls_stack',
         'conf',
         'exception_prefix',
         'func',
-        'hint',
-        'hint_or_sane',
+        'hint_sane',
         'pith',
         'pith_name',
         'random_int',
-        'typevar_to_hint',
+        'cause_str_or_none',
     ))
     '''
-    Frozen set of the names of all parameters accepted by the :meth:`init`
+    Frozen set of the names of *all* instance variables whose values will be
+    copied as the default values of all **unpassed parameters** (i.e.,
+    parameters *not* explicitly passed to the :meth:`permute_cause` method),
+    defined as a set to enable efficient membership testing.
+
+    Note that the :attr:`hint_sign` instance variable is intentionally omitted.
+    This variable's value is unique to the current cause and thus *not* safely
+    copyable from parent to child hints by the :meth:`permute_cause` method.
+    '''
+
+
+    _INIT_ARG_NAMES = _COPY_VAR_NAMES | frozenset(('hint_sign',))
+    '''
+    Frozen set of the names of *all* parameters accepted by the :meth:`init`
     method, defined as a set to enable efficient membership testing.
     '''
 
     # ..................{ INITIALIZERS                       }..................
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # CAUTION: Whenever adding, deleting, or renaming any parameter accepted by
-    # this method, make similar changes to the "_INIT_PARAM_NAMES" set above.
+    # this method, make similar changes to the "_INIT_ARG_NAMES" set above.
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     def __init__(
         self,
 
         # Mandatory parameters.
+        hint_sane: HintSane,
         cause_indent: str,
         cls_stack: TypeStack,
         conf: BeartypeConf,
@@ -265,49 +268,61 @@ class ViolationCause(object):
         random_int: Optional[int],
 
         # Optional parameters.
-        hint: Union[Hint, Iota] = SENTINEL,
-        hint_or_sane: Union[HintOrSanifiedData, Iota] = SENTINEL,
         cause_str_or_none: Optional[str] = None,
-        typevar_to_hint: TypeVarToHint = FROZENDICT_EMPTY,
+        hint_sign: HintSignOrNoneOrSentinel = SENTINEL,
     ) -> None:
         '''
-        Initialize this type-checking violation cause finder.
+        Initialize this violation cause.
 
         Parameters
         ----------
-        hint : Hint
-            Unsanified hint to validate this object against. This parameter is
-            mutually exclusive with the competing ``hint_or_sane`` parameter.
-            Defaults to the sentinel placeholder such that either:
+        hint_sign : Union[Optional[HintSign], Iota], default: SENTINEL
+            Either:
 
-            * This parameter is unpassed (thus, the sentinel) and the
-              ``hint_or_sane`` parameter is passed (thus, *not* the sentinel).
-            * This parameter is passed (thus, *not* the sentinel) and the
-              ``hint_or_sane`` parameter is unpassed (thus, the sentinel).
-        hint_or_sane : HintOrSanifiedData
-            Sanified hint *or* **supplementary metadata** (i.e.,
-            :class:`.HintSanifiedData` object) generated by the sanification of
-            this hint to validate this object against. This parameter is
-            mutually exclusive with the competing ``hint_or_sane`` parameter.
-            Defaults to the sentinel placeholder such that either:
+            * If this child hint is uniquely identified by a **non-default
+              sign** (i.e., a singleton instance of the :class:`.HintSign` class
+              *other* than the standard sign returned by the
+              :func:`.get_hint_pep_sign_or_none` getter), this sign.
+            * Else, the sentinel placeholder, in which case this parameter
+              defaults to the **default sign** (i.e., the standard sign returned
+              by the :func:`.get_hint_pep_sign_or_none` getter).
 
-            * This parameter is unpassed (thus, the sentinel) and the
-              ``hint_or_sane`` parameter is passed (thus, *not* the sentinel).
-            * This parameter is passed (thus, *not* the sentinel) and the
-              ``hint_or_sane`` parameter is unpassed (thus, the sentinel). In
-              this case, this parameter is defined as either:
+            Defaults to the sentinel placeholder. This parameter should
+            typically *not* be passed. Almost all hints are uniquely identified
+            by the default sign. A small subset of hints, however, concurrently
+            satisfy the detection criteria for multiple signs and are thus
+            identifiable with multiple signs. This parameter supports those
+            hints by enabling callers to call this method multiple times with
+            the same hint passed different signs.
 
-              * If this hint is reducible to:
+            Prominent examples include:
 
-                * An ignorable lower-level hint, :obj:`typing.Any`.
-                * An unignorable lower-level hint, either:
+            * :pep:`484`- and :pep:`585`-compliant unsubscripted generics --
+              which, due to being user-defined types, may subclass another
+              PEP-compliant :mod:`typing` superclass also identifiable by
+              another sign. Prominent examples include:
 
-                  * If reducing this hint to that lower-level hint generates
-                    supplementary metadata, that metadata.
-                  * Else, that lower-level hint alone.
+              * **Generic typed dictionaries** identifiable as both the
+                :data:`.HintSignPep484585GenericUnsubscripted` sign *and* the
+                :data:`HintSignTypedDict` sign for :pep:`589`-compliant typed
+                dictionaries: e.g.,
 
-              * Else, this hint is irreducible. In this case, this hint
-                unmodified.
+                .. code-block:: python
+
+                   from typing import Generic, TypedDict
+                   class GenericTypedDict[T](TypedDict, Generic[T]):
+                       generic_item: T
+
+              * **Generic named tuples** identifiable as both the
+                :data:`.HintSignPep484585GenericUnsubscripted` sign *and* the
+                :data:`HintSignNamedTuple` sign for :pep:`484`-compliant named
+                tuples: e.g.,
+
+                .. code-block:: python
+
+                   from typing import Generic, NamedTuple
+                   class GenericNamedTuple[T](NamedTuple, Generic[T]):
+                       generic_item: T
 
         See the class docstring for a description of all remaining parameters.
         '''
@@ -323,14 +338,21 @@ class ViolationCause(object):
             f'{repr(cause_str_or_none)} not string or "None".')
         assert isinstance(exception_prefix, str), (
             f'{repr(exception_prefix)} not string.')
-        # assert isinstance(is_hint_root, bool), (
-        #     f'{repr(is_hint_root)} not boolean.')
+        assert isinstance(hint_sane, HintSane), (
+            f'{repr(hint_sane)} not sanified metadata.')
         assert isinstance(pith_name, NoneTypeOr[str]), (
             f'{repr(pith_name)} not string or "None".')
         assert isinstance(random_int, NoneTypeOr[int]), (
             f'{repr(random_int)} not integer or "None".')
-        assert isinstance(typevar_to_hint, FrozenDict), (
-            f'{repr(typevar_to_hint)} not frozen dictionary.')
+
+        # If the caller did *NOT* pass a non-default sign identifying this hint,
+        # default this sign to the default sign identifying this hint.
+        if hint_sign is SENTINEL:
+            hint_sign = get_hint_pep_sign_or_none(hint_sane.hint)
+        # Else, the caller passed a non-default sign identifying this hint.
+        # Preserve this sign as is.
+        assert isinstance(hint_sign, NoneTypeOr[HintSign]), (
+            f'{repr(hint_sane)} neither hint sign, "None", nor "SENTINEL".')
 
         # Classify all passed parameters.
         self.cause_indent = cause_indent
@@ -339,111 +361,97 @@ class ViolationCause(object):
         self.conf = conf
         self.exception_prefix = exception_prefix
         self.func = func
+        self.hint_sane = hint_sane
+        self.hint_sign = hint_sign  # pyright: ignore
         self.pith = pith
         self.pith_name = pith_name
         self.random_int = random_int
-        self.typevar_to_hint = typevar_to_hint
 
         # Nullify all remaining parameters for safety.
         self.hint_childs = None  # type: ignore[assignment]
-        self.hint_or_sane_childs = None  # type: ignore[assignment]
+        self.hint_childs_sane = None  # type: ignore[assignment]
 
-        # If the caller passed *NO* sanified hint...
-        if hint_or_sane is SENTINEL:
-            assert hint is not SENTINEL, (
-                f'"hint" {repr(hint)} and '
-                f'"hint_or_sane" {repr(hint_or_sane)} parameters both unpassed.'
-            )
+        # Sane hint sanified from this possibly insane hint.
+        self.hint = hint_sane.hint
 
-            # Sane hint sanified from this possibly insane hint if sanifying
-            # this hint did not generate supplementary metadata *OR* that
-            # metadata (i.e., if doing so generated supplementary metadata).
-            hint_or_sane = self.sanify_hint_child(hint)  # type: ignore[arg-type]
-            # print(f'Sanified error parent hint {repr(hint)} to {repr(hint_or_sane)}.')
-        # Else, the caller passed a sanified hint. In this case...
-        else:
-            # Silently ignore the passed unsanified hint if any by simply
-            # deleting the latter.
-            #
-            # Note that we would ideally raise an exception if the caller also
-            # passed an unsanified hint, but that doing so would raise
-            # complications with our current implementation of the permute()
-            # method. Since this dataclass *ONLY* applies to private
-            # functionality *NEVER* exposed to end users, a bit of wonkiness in
-            # this private API is currently an acceptable tradeoff.
-            # Assert that the caller passed an unsanified hint.
-            del hint
+        # Initialize the "hint_childs" and "hint_childs_sane" instance variables
+        # of this violation cause.
+        self._init_hint_childs()
 
-        # Sane hint sanified from this possibly insane hint *AND* the
-        # corresponding type variable lookup table unpacked from this metadata.
-        self.hint, self.typevar_to_hint = unpack_hint_or_sane(hint_or_sane)  # type: ignore[arg-type]
 
-        # Sign uniquely identifying this hint if this hint is PEP-compliant *OR*
-        # "None" otherwise (i.e., if this hint is PEP-noncompliant).
-        self.hint_sign = get_hint_pep_sign_or_none(self.hint)
+    def _init_hint_childs(self) -> None:
+        '''
+        Initialize the :attr:`hint_childs` and :attr:`hint_childs_sane` instance
+        variables of this violation cause.
+        '''
 
-        #FIXME: Refactor into a new private method for maintainability, please.
-        # If this hint is both...
+        # If this hint is either...
         if (
-            # Unignorable *AND*...
-            self.hint is not Any and
-            # PEP-compliant...
-            is_hint_pep(self.hint)
+            # Ignorable *OR*...
+            self.hint_sane is HINT_SANE_IGNORABLE or
+            # PEP-noncompliant...
+            not is_hint_pep(self.hint)
         ):
-            # Tuple of the zero or more arguments subscripting this hint.
-            hint_childs_insane = get_hint_pep_args(self.hint)
+            # Then this hint *CANNOT* by definition be subscripted by any
+            # meaningful child hints. Silently reduce to a noop.
+            return
+        # Else, this is an unignorable PEP-compliant hint. Since this hint
+        # *COULD* be subscripted by meaningful child hints, continue.
 
-            # List of the zero or more possibly ignorable sane child hints
-            # subscripting this parent hint, initialized to the empty list.
-            hint_childs_sane = []
+        # Tuple of the zero or more arguments subscripting this hint.
+        hint_childs_insane = get_hint_pep_args(self.hint)
 
-            # List of the zero or more possibly ignorable metadata generated by
-            # sanifying these child hints, initialized to the empty list.
-            hint_or_sane_childs_sane = []
+        # List of the zero or more possibly ignorable sane child hints
+        # subscripting this parent hint, initialized to the empty list.
+        hint_childs = []
 
-            # For each possibly ignorable insane child hints subscripting this
-            # parent hint...
-            for hint_child_insane in hint_childs_insane:
-                # Sane child hint sanified from this possibly insane child hint.
-                hint_child_sane: Hint = None  # pyright: ignore
+        # List of the zero or more possibly ignorable metadata generated by
+        # sanifying these child hints, initialized to the empty list.
+        hint_childs_sane = []
 
-                # Sane child hint sanified from this possibly insane child hint
-                # if sanifying this child hint did not generate supplementary
-                # metadata *OR* that metadata otherwise (i.e., if sanifying this
-                # child hint generated supplementary metadata).
-                hint_or_sane_child_sane: HintOrSanifiedData = None  # type: ignore[assignment]
+        # For each possibly ignorable insane child hints subscripting this
+        # parent hint...
+        for hint_child_insane in hint_childs_insane:
+            # Sane child hint sanified from this possibly insane child hint.
+            hint_child: Hint = None  # pyright: ignore
 
-                # If this child hint is PEP-compliant...
-                #
-                # Note that arbitrary PEP-noncompliant arguments *CANNOT* be
-                # safely sanitized. Why? Because arbitrary arguments are *NOT*
-                # necessarily valid hints. Consider the hint "tuple[()]", where
-                # the argument "()" is invalid as a hint but valid an argument
-                # to that hint.
-                if is_hint_pep(hint_child_insane):
-                    # Sanify this child hint into this metadata.
-                    hint_or_sane_child_sane = self.sanify_hint_child(
-                        hint_child_insane)
+            # Metadata encapsulating the sanification of this child hint.
+            hint_child_sane: HintSane = None  # type: ignore[assignment]
 
-                    # Sane child hint encapsulated by this metadata.
-                    hint_child_sane = get_hint_or_sane_hint(
-                        hint_or_sane_child_sane)
-                # Else, this child hint is PEP-noncompliant. In this case,
-                # preserve this child hint as is.
-                else:
-                    hint_child_sane = hint_or_sane_child_sane = (
-                        hint_child_insane)
+            # If this child hint is either...
+            #
+            # Note that arbitrary PEP-noncompliant arguments *CANNOT* be safely
+            # sanified. Arbitrary arguments are *NOT* necessarily valid hints.
+            # Consider the hint "tuple[()]", where the argument "()" is invalid
+            # as a hint but valid an argument to that hint.
+            if (
+                # PEP-compliant *OR*...
+                is_hint_pep(hint_child_insane) or
+                # A type, which is effectively PEP 484-compliant.
+                isinstance(hint_child_insane, type)
+            ):
+                # Sanify this child hint into this metadata.
+                hint_child_sane = self.sanify_hint_child(
+                    hint_child_insane=hint_child_insane,
+                    hint_parent_sane=self.hint_sane,
+                )
 
-                # Append this possibly ignorable sane child hint and
-                # supplementary metadata to these lists.
-                hint_childs_sane.append(hint_child_sane)
-                hint_or_sane_childs_sane.append(hint_or_sane_child_sane)
+                # Sane child hint encapsulated by this metadata.
+                hint_child = hint_child_sane.hint
+            # Else, this child hint is PEP-noncompliant. In this case, preserve
+            # this child hint as is.
+            else:
+                hint_child = hint_child_sane = hint_child_insane
 
-            # Tuples of the zero or more possibly ignorable sane child hints and
-            # supplementary metadatum, coerced from these lists.
-            self.hint_childs = tuple(hint_childs_sane)
-            self.hint_or_sane_childs = tuple(hint_or_sane_childs_sane)
-        # Else, this hint is PEP-noncompliant (e.g., isinstanceable class).
+            # Append this possibly ignorable sane child hint and supplementary
+            # metadata to these lists.
+            hint_childs.append(hint_child)
+            hint_childs_sane.append(hint_child_sane)
+
+        # Tuples of the zero or more possibly ignorable sane child hints and
+        # supplementary metadatum, coerced from these lists.
+        self.hint_childs = tuple(hint_childs)
+        self.hint_childs_sane = tuple(hint_childs_sane)
 
     # ..................{ DUNDERS                            }..................
     def __repr__(self) -> str:
@@ -456,18 +464,18 @@ class ViolationCause(object):
         return (
             f'{self.__class__.__name__}('
             f'hint={repr(self.hint)}, '
+            f'hint_sane={repr(self.hint_sane)}, '
             f'hint_sign={repr(self.hint_sign)}, '
             f'hint_childs={repr(self.hint_childs)}, '
-            f'hint_or_sane_childs={repr(self.hint_or_sane_childs)}, '
-            f'conf={repr(self.conf)}, '
+            f'hint_childs_sane={repr(self.hint_childs_sane)}, '
             f'cause_indent={repr(self.cause_indent)}, '
             f'cause_str_or_none={repr(self.cause_str_or_none)}, '
             f'cls_stack={repr(self.cls_stack)}, '
+            f'conf={repr(self.conf)}, '
             f'func={repr(self.func)}, '
             f'pith={repr(self.pith)}, '
             f'pith_name={repr(self.pith_name)}, '
             f'random_int={repr(self.random_int)}, '
-            f'typevar_to_hint={repr(self.typevar_to_hint)}, '
             f'exception_prefix={repr(self.exception_prefix)}, '
             f')'
         )
@@ -483,12 +491,12 @@ class ViolationCause(object):
         This method is intentionally generalized to support objects both
         satisfying and *not* satisfying hints as equally valid use cases. While
         the parent
-        :func:`beartype._check.error.errget.get_func_pith_violation` function
+        :func:`beartype._check.error.errmain.get_func_pith_violation` function
         calling this method is *always* passed an object *not* satisfying the
         passed hint, this method is under no such constraints. Why? Because this
         method is also called to find which of an arbitrary number of objects
         transitively nested in the object passed to
-        :func:`beartype._check.error.errget.get_func_pith_violation` fails to
+        :func:`beartype._check.error.errmain.get_func_pith_violation` fails to
         satisfy the corresponding hint transitively nested in the hint passed to
         that function.
 
@@ -521,53 +529,20 @@ class ViolationCause(object):
             * PEP-compliant but no getter function has been implemented to
               handle this category of PEP-compliant type hint yet.
         '''
+        # print(f'Finding cause for {self.hint} identified by {self.hint_sign}...')
 
         # If this hint is ignorable, all possible objects satisfy this hint.
         # Since this hint *CANNOT* (by definition) be the cause of this failure,
         # return the same cause as is.
-        if self.hint is Any:
+        if self.hint_sane is HINT_SANE_IGNORABLE:
             return self
         # Else, this hint is unignorable.
 
         # Getter function returning the desired string.
         cause_finder: Callable[[ViolationCause], ViolationCause] = None  # type: ignore[assignment]
 
-        #FIXME: Trivially simplify this method by:
-        #* Define a new find_cause_nonpep() function elsewhere whose body is
-        #  the body of this "if" conditional branch.
-        #* Register this function with HINT_SIGN_TO_GET_CAUSE_FUNC: e.g.,
-        #  HINT_SIGN_TO_GET_CAUSE_FUNC = {
-        #      ...,
-        #      None: find_cause_nonpep,
-        #  }
-        #* Remove this "if" conditional branch.
-
-        # If *NO* sign uniquely identifies this hint, this hint is either
-        # PEP-noncompliant *OR* only contextually PEP-compliant in certain
-        # specific use cases. In either case...
-        if self.hint_sign is None:
-            # Avoid circular import dependencies.
-            from beartype._check.error._errtype import (
-                find_cause_instance_types_tuple,
-                find_cause_instance_type,
-            )
-
-            # If this hint is a tuple union, defer to the finder specific to
-            # tuple unions.
-            if isinstance(self.hint, tuple):
-                cause_finder = find_cause_instance_types_tuple
-            # Else, this hint is *NOT* a tuple union. In this case, assume this
-            # hint to be an isinstanceable class by deferring to the finder
-            # specific to isinstanceable classes.
-            #
-            # Note that if this assumption is *NOT* the case, this finder
-            # subsequently raises a human-readable exception.
-            else:
-                cause_finder = find_cause_instance_type
-        # Else, this hint is PEP-compliant.
-        #
         # If this hint...
-        elif (
+        if (
             # Originates from an origin type and may thus be shallowly
             # type-checked against that type *AND is either...
             self.hint_sign in HINT_SIGNS_ORIGIN_ISINSTANCEABLE and (
@@ -603,7 +578,7 @@ class ViolationCause(object):
             # yet, raise an exception.
             if cause_finder is None:
                 raise _BeartypeCallHintPepRaiseException(
-                    f'{self.exception_prefix} type hint '
+                    f'{self.exception_prefix}type hint '
                     f'{repr(self.hint)} unsupported (i.e., no '
                     f'"find_cause_"-prefixed getter function defined '
                     f'for this category of hint).'
@@ -616,27 +591,29 @@ class ViolationCause(object):
         return cause_finder(self)
 
     # ..................{ PERMUTERS                          }..................
-    def permute(self, **kwargs) -> 'ViolationCause':
+    def permute_cause(self, **kwargs) -> 'ViolationCause':
         '''
-        Shallow copy of this object such that each passed keyword parameter
-        overwrites the instance variable of the same name in this copy.
+        Shallow copy of this violation cause such that each passed keyword
+        parameter overwrites the instance variable of the same name in this
+        copy.
 
         Parameters
         ----------
         Keyword parameters of the same name and type as instance variables of
-        this object (e.g., ``hint: Hint``, ``pith: object``).
+        this object (e.g., ``pith: object``).
 
         Returns
         -------
         ViolationCause
-            Shallow copy of this object such that each keyword parameter
-            overwrites the instance variable of the same name in this copy.
+            Shallow copy of this violation cause such that each keyword
+            parameter overwrites the instance variable of the same name in this
+            copy.
 
         Raises
         ------
         _BeartypeCallHintPepRaiseException
             If the name of any passed keyword parameter is *not* that of an
-            existing instance variable of this object.
+            existing instance variable of this violation cause.
 
         Examples
         --------
@@ -648,7 +625,7 @@ class ViolationCause(object):
            ...     cause_indent='',
            ...     exception_prefix='List of integers',
            ... )
-           >>> sleuth_copy = sleuth.permute(pith=[24,])
+           >>> sleuth_copy = sleuth.permute_cause(pith=[24,])
            >>> sleuth_copy.pith
            [24,]
            >>> sleuth_copy.hint
@@ -659,57 +636,135 @@ class ViolationCause(object):
         return permute_object(
             obj=self,
             init_arg_name_to_value=kwargs,
-            init_arg_names=self._INIT_PARAM_NAMES,
+            init_arg_names=self._INIT_ARG_NAMES,
+            copy_var_names=self._COPY_VAR_NAMES,
             exception_cls=_BeartypeCallHintPepRaiseException,
         )
 
-    # ..................{ SANIFIERS                          }..................
-    def sanify_hint_child(self, hint: Hint) -> HintOrSanifiedData:
+
+    def permute_cause_hint_child_insane(
+        self, hint_child_insane: Hint, **kwargs) -> 'ViolationCause':
         '''
-        Type hint sanified (i.e., sanitized) from the passed **possibly insane
-        child type hint** (i.e., hint transitively subscripting the root type
-        hint annotating a parameter or return of the currently decorated
-        callable) if this hint is both reducible and ignorable, this hint
-        unmodified if this hint is both irreducible and ignorable, and
-        :object:`typing.Any` otherwise (i.e., if this hint is ignorable).
+        Shallow copy of this violation cause such that each passed keyword
+        parameter overwrites the instance variable of the same name in this copy
+        *after* sanifying (i.e., sanitizing) the passed **possibly insane child
+        hint** (i.e., child hint that has yet to be sanified subscripting the
+        current hint encapsulated by this cause) and passing the metadata
+        encapsulating that sanification as the ``hint_sane`` parameter of this
+        dictionary.
+
+        Parameters
+        ----------
+        hint_child_insane : Hint
+            Possibly insane child hint to be sanified.
+
+        All other keyword parameters are of the same name and type as instance
+        variables of this object (e.g., ``pith: object``).
+
+        Returns
+        -------
+        ViolationCause
+            Shallow copy of this violation cause, permuted as detailed above.
+
+        Raises
+        ------
+        _BeartypeCallHintPepRaiseException
+            If the name of any passed keyword parameter is *not* that of an
+            existing instance variable of this violation cause.
+
+        See Also
+        --------
+        :meth:`permute_cause`
+            Further details.
+        '''
+
+        # Metadata encapsulating the sanification of the passed hint relative to
+        # the current previously sanified hint, which effectively serves as the
+        # "parent" of the passed hint for all intents and purposes.
+        hint_sane = self.sanify_hint_child(
+            hint_child_insane=hint_child_insane,
+            hint_parent_sane=self.hint_sane,
+        )
+
+        # Violation cause permuted from this metadata and these keywords.
+        cause_permuted = self.permute_cause(hint_sane=hint_sane, **kwargs)
+
+        # Return this permuted cause.
+        return cause_permuted
+
+    # ..................{ SANIFIERS                          }..................
+    def sanify_hint_child(
+        self,
+
+        # Mandatory parameters.
+        hint_child_insane: Hint,
+
+        # Optional parameters.
+        hint_parent_sane: Optional[HintSane] = None,
+    ) -> HintSane:
+        '''
+        Metadata encapsulating the sanification (i.e., sanitization) of the
+        passed **possibly insane child type hint** (i.e., possibly
+        PEP-noncompliant hint transitively subscripting the root hint annotating
+        a parameter or return of the currently decorated callable) if this hint
+        is both reducible and unignorable, this hint unmodified if this hint is
+        both irreducible and unignorable, or :obj:`.HINT_SANE_IGNORABLE` otherwise
+        (i.e., if this hint is ignorable).
 
         This method is merely a convenience wrapper for the lower-level
         :func:`.sanify_hint_child` sanifier.
 
         Parameters
         ----------
-        hint : Hint
-            Type hint to be sanified.
+        hint_child_insane : Hint
+            Child type hint to be sanified.
+        hint_parent_sane : HintSane
+            **Sanified parent type hint metadata** (i.e., immutable and thus
+            hashable object encapsulating *all* metadata previously returned by
+            :mod:`beartype._check.convert.convsanify` sanifiers after sanitizing
+            the possibly PEP-noncompliant parent hint of this child hint into a
+            fully PEP-compliant parent hint).
+        hint_parent_sane : Optional[HintSane], default: None
+            **Sanified parent type hint metadata** (i.e., immutable and thus
+            hashable object encapsulating *all* metadata previously returned by
+            :mod:`beartype._check.convert.convsanify` sanifiers after sanitizing
+            the possibly PEP-noncompliant parent hint of this child hint into a
+            fully PEP-compliant parent hint). Defaults to :data:`None`, in which
+            case this parameter actually defaults to ``self.hint_sane``, the
+            previously sanified metadata encapsulating the direct parent hint of
+            this child hint. Since this default suffices in the common case,
+            callers should only pass this parameter when explicitly sanifying
+            the parent hint of this child hint.
 
         Returns
         -------
-        HintOrSanifiedData
+        HintSane
             Either:
 
-            * If the passed hint is reducible to:
-
-              * An ignorable lower-level hint, :obj:`typing.Any`.
-              * An unignorable lower-level hint, either:
-
-                * If reducing this hint to that lower-level hint generates
-                  supplementary metadata, that metadata.
-                * Else, that lower-level hint alone.
-
-            * Else, this hint is irreducible. In this case, this hint
-              unmodified.
+            * If this child hint is ignorable, :data:`.HINT_SANE_IGNORABLE`.
+            * Else if this unignorable child hint is reducible to another hint,
+              metadata encapsulating this reduction.
+            * Else, this unignorable child hint is irreducible. In this case,
+              metadata encapsulating this child hint unmodified.
         '''
 
-        # Sane hint sanified from this possibly insane hint if sanifying this
-        # hint did not generate supplementary metadata *OR* that metadata
-        # otherwise (i.e., if doing so generated supplementary metadata).
-        hint_or_sane_child = sanify_hint_child(
-            hint=hint,
+        # If the caller explicitly passed *NO* sanified parent hint metadata,
+        # default this metadata to that of the currently visited hint.
+        if hint_parent_sane is None:
+            hint_parent_sane = self.hint_sane
+        # Else, the caller explicitly passed sanified parent hint metadata.
+        # Silently preserve this metadata as is.
+
+        # Metadata encapsulating the sanification of this child hint.
+        hint_sane_child = sanify_hint_child(
+            hint=hint_child_insane,
+            hint_parent_sane=hint_parent_sane,
             cls_stack=self.cls_stack,
             conf=self.conf,
             pith_name=self.pith_name,
-            typevar_to_hint=self.typevar_to_hint,
             exception_prefix=self.exception_prefix,
         )
+        # print(f'Sanified child hint {hint_child_insane} to {hint_sane_child} of parent {hint_parent_sane}!')
 
         # Return this metadata.
-        return hint_or_sane_child
+        return hint_sane_child
