@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -16,10 +16,18 @@ from beartype.typing import (
     Any,
     Optional,
 )
-from beartype._cave._cavefast import MethodBoundInstanceOrClassType
-from beartype._data.hint.datahintfactory import TypeGuard
+from beartype._cave._cavefast import (
+    MethodBoundInstanceOrClassType,
+    MethodDecoratorBuiltinTypes,
+    MethodDecoratorClassOrStaticTypes,
+    MethodDecoratorClassType,
+    MethodDecoratorPropertyType,
+    MethodDecoratorStaticType,
+)
+from beartype._data.hint.datahintpep import TypeIs
 from beartype._data.hint.datahinttyping import (
     Codeobjable,
+    MethodDescriptorBuiltin,
     TypeException,
 )
 # from beartype._util.cache.utilcachecall import callable_cached
@@ -96,12 +104,12 @@ def die_unless_func_python(
 
     See Also
     --------
-    :func:`.is_func_python`
+    :func:`.is_func_codeobjable`
         Further details.
     '''
 
     # If that callable is *NOT* pure-Python, raise an exception.
-    if not is_func_python(func):
+    if not is_func_codeobjable(func):
         assert isinstance(exception_cls, type), (
             f'{repr(exception_cls)} not class.')
         assert issubclass(exception_cls, Exception), (
@@ -176,6 +184,64 @@ def die_unless_func_boundmethod(
     # Else, this object is a bound method descriptor.
 
 
+#FIXME: Unit test us up, please.
+def die_unless_func_class_or_static_method(
+    # Mandatory parameters.
+    func: Any,
+
+    # Optional parameters.
+    exception_cls: TypeException = _BeartypeUtilCallableException,
+    exception_prefix: str = '',
+) -> None:
+    '''
+    Raise an exception unless the passed object is a **C-based unbound class or
+    static method descriptor** (i.e., method decorated by either the builtin
+    :class:`classmethod` or :class:`staticmethod` decorators, yielding a
+    non-callable instance of that decorator class implemented in low-level C and
+    accessible via the low-level :attr:`object.__dict__` dictionary rather than
+    as class or instance attributes).
+
+    Parameters
+    ----------
+    func : Any
+        Object to be inspected.
+    exception_cls : TypeException, optional
+        Type of exception to be raised. Defaults to
+        :exc:`._BeartypeUtilCallableException`.
+    exception_prefix : str, optional
+        Human-readable substring prefixing raised exception messages. Defaults
+        to the empty string.
+
+    Raises
+    ------
+    exception_cls
+         If the passed object is *not* a class or static method descriptor.
+
+    See Also
+    --------
+    :func:`.is_func_classmethod`
+        Further details.
+    '''
+
+    # If this object is neither a class *NOR* static method descriptor, raise an
+    # exception.
+    if not isinstance(func, MethodDecoratorClassOrStaticTypes):
+        assert isinstance(exception_cls, type), (
+            f'{repr(exception_cls)} not class.')
+        assert issubclass(exception_cls, Exception), (
+            f'{repr(exception_cls)} not exception subclass.')
+        assert isinstance(exception_prefix, str), (
+            f'{repr(exception_prefix)} not string.')
+
+        # Raise a human-readable exception.
+        raise exception_cls(
+            f'{exception_prefix}{repr(func)} not '
+            f'C-based unbound @classmethod or @staticmethod descriptor.'
+        )
+    # Else, this object is a class or static method descriptor.
+
+
+#FIXME: Currently unused, but extensively tested. *shrug*
 def die_unless_func_classmethod(
     # Mandatory parameters.
     func: Any,
@@ -285,6 +351,7 @@ def die_unless_func_property(
     # Else, this object is a property method descriptor.
 
 
+#FIXME: Currently unused, but extensively tested. *shrug*
 def die_unless_func_staticmethod(
     # Mandatory parameters.
     func: Any,
@@ -340,7 +407,34 @@ def die_unless_func_staticmethod(
     # Else, this object is a static method descriptor.
 
 # ....................{ TESTERS                            }....................
-def is_func_lambda(func: Any) -> TypeGuard[Callable]:
+def is_func_codeobjable(func: object) -> TypeIs[Callable]:
+    '''
+    :data:`True` only if the passed object is **code-objectable** (i.e., either
+    a pure-Python callable, low-level code object underlying a pure-Python
+    callable, or related object encapsulating such a low-level code object).
+
+    This tester effectively tests whether this object is a **pure-Python
+    callable** (i.e., implemented in Python as either a function or method
+    rather than in C as either a builtin bundled with the active Python
+    interpreter *or* third-party C extension function).
+
+    Parameters
+    ----------
+    func : object
+        Object to be inspected.
+
+    Returns
+    -------
+    bool
+        :data:`True` only if this object is code-objectable.
+    '''
+
+    # Return true only if a pure-Python code object underlies this object.
+    # C-based callables are associated with *NO* code objects.
+    return get_func_codeobj_or_none(func) is not None
+
+
+def is_func_lambda(func: Any) -> TypeIs[Callable]:
     '''
     :data:`True` only if the passed object is a **pure-Python lambda function**
     (i.e., function declared as a ``lambda`` expression embedded in a larger
@@ -360,7 +454,7 @@ def is_func_lambda(func: Any) -> TypeGuard[Callable]:
     # Return true only if this both...
     return (
         # This callable is pure-Python *AND*...
-        is_func_python(func) and
+        is_func_codeobjable(func) and
         # This callable's name is the lambda-specific placeholder name
         # initially given by Python to *ALL* lambda functions. Technically,
         # this name may be externally changed by malicious third parties after
@@ -374,32 +468,9 @@ def is_func_lambda(func: Any) -> TypeGuard[Callable]:
         func.__name__ == FUNC_NAME_LAMBDA
     )
 
-
-def is_func_python(func: object) -> TypeGuard[Callable]:
-    '''
-    :data:`True` only if the passed object is a **pure-Python callable** (i.e.,
-    implemented in Python as either a function or method rather than in C as
-    either a builtin bundled with the active Python interpreter *or*
-    third-party C extension function).
-
-    Parameters
-    ----------
-    func : object
-        Object to be inspected.
-
-    Returns
-    -------
-    bool
-        :data:`True` only if this object is a pure-Python callable.
-    '''
-
-    # Return true only if a pure-Python code object underlies this object.
-    # C-based callables are associated with *NO* code objects.
-    return get_func_codeobj_or_none(func) is not None
-
 # ....................{ TESTERS ~ descriptor               }....................
 #FIXME: Unit test us up, please.
-def is_func_boundmethod(func: Any) -> TypeGuard[MethodBoundInstanceOrClassType]:
+def is_func_boundmethod(func: Any) -> TypeIs[MethodBoundInstanceOrClassType]:
     '''
     :data:`True` only if the passed object is a **C-based bound instance method
     descriptor** (i.e., callable implicitly instantiated and assigned on the
@@ -433,15 +504,44 @@ def is_func_boundmethod(func: Any) -> TypeGuard[MethodBoundInstanceOrClassType]:
     # Only the penitent one-liner shall pass.
     return isinstance(func, MethodBoundInstanceOrClassType)
 
+# ....................{ TESTERS ~ descriptor : uncallable  }....................
+#FIXME: Unit test us up, please.
+#FIXME: Currently unused but preserved for posterity. We'll want this someday!
+# def is_func_class_property_or_static_method(func: Any)  -> TypeIs[
+#     MethodDescriptorBuiltin]:
+#     '''
+#     :data:`True` only if the passed object is an **unbound class, property, or
+#     static method descriptor** (i.e., C-based decorator type builtin to Python
+#     whose instance is typically uncallable but encapsulates a callable
+#     pure-Python method).
+#
+#     These method objects are *not* callable, as their implementations fail to
+#     define the ``__call__()`` dunder method.
+#
+#     Parameters
+#     ----------
+#     func : object
+#         Object to be inspected.
+#
+#     Returns
+#     -------
+#     bool
+#         :data:`True` only if this object is an unbound class, property, or
+#         static method descriptor.
+#     '''
+#
+#     # Line up for the one-liner you never knew you needed in your life.
+#     return isinstance(func, MethodDecoratorBuiltinTypes)
 
-def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
+
+def is_func_classmethod(func: Any) -> TypeIs[MethodDecoratorClassType]:
     '''
-    :data:`True` only if the passed object is a **C-based unbound class method
+    :data:`True` only if the passed object is an **unbound class method
     descriptor** (i.e., method decorated by the builtin :class:`classmethod`
     decorator, yielding a non-callable instance of that :class:`classmethod`
-    decorator class implemented in low-level C and accessible via the
-    low-level :attr:`object.__dict__` dictionary rather than as class or
-    instance attributes).
+    decorator class implemented in low-level C and accessible via the low-level
+    :attr:`object.__dict__` dictionary rather than as class or instance
+    attributes).
 
     Caveats
     -------
@@ -462,15 +562,14 @@ def is_func_classmethod(func: Any) -> TypeGuard[classmethod]:
     Returns
     -------
     bool
-        :data:`True` only if this object is a C-based unbound class method
-        descriptor.
+        :data:`True` only if this object is an unbound class method descriptor.
     '''
 
     # Now you too have seen the pure light of the one-liner.
-    return isinstance(func, classmethod)
+    return isinstance(func, MethodDecoratorClassType)
 
 
-def is_func_property(func: Any) -> TypeGuard[property]:
+def is_func_property(func: Any) -> TypeIs[MethodDecoratorPropertyType]:
     '''
     :data:`True` only if the passed object is a **C-based unbound property
     method descriptor** (i.e., method decorated by the builtin :class:`property`
@@ -499,10 +598,10 @@ def is_func_property(func: Any) -> TypeGuard[property]:
     '''
 
     # We rejoice in the shared delight of one-liners.
-    return isinstance(func, property)
+    return isinstance(func, MethodDecoratorPropertyType)
 
 
-def is_func_staticmethod(func: Any) -> TypeGuard[staticmethod]:
+def is_func_staticmethod(func: Any) -> TypeIs[MethodDecoratorStaticType]:
     '''
     :data:`True` only if the passed object is a **C-based unbound static method
     descriptor** (i.e., method decorated by the builtin :class:`staticmethod`
@@ -533,10 +632,10 @@ def is_func_staticmethod(func: Any) -> TypeGuard[staticmethod]:
     '''
 
     # Does the one-liner have Buddhahood? Mu.
-    return isinstance(func, staticmethod)
+    return isinstance(func, MethodDecoratorStaticType)
 
 # ....................{ TESTERS ~ async                    }....................
-def is_func_async(func: object) -> TypeGuard[Callable]:
+def is_func_async(func: object) -> TypeIs[Callable]:
     '''
     :data:`True` only if the passed object is an **asynchronous callable
     factory** (i.e., awaitable factory callable implicitly creating and
@@ -598,7 +697,7 @@ def is_func_async(func: object) -> TypeGuard[Callable]:
     )
 
 
-def is_func_coro(func: object) -> TypeGuard[Callable]:
+def is_func_coro(func: object) -> TypeIs[Callable]:
     '''
     :data:`True` only if the passed object is an **asynchronous coroutine
     factory** (i.e., awaitable callable containing *no* ``yield`` expression
@@ -636,7 +735,7 @@ def is_func_coro(func: object) -> TypeGuard[Callable]:
     )
 
 
-def is_func_async_generator(func: object) -> TypeGuard[Callable]:
+def is_func_async_generator(func: object) -> TypeIs[Callable]:
     '''
     :data:`True` only if the passed object is an **asynchronous generator
     factory** (i.e., awaitable callable containing one or more ``yield``
@@ -674,7 +773,7 @@ def is_func_async_generator(func: object) -> TypeGuard[Callable]:
     )
 
 # ....................{ TESTERS ~ sync                     }....................
-def is_func_sync_generator(func: object) -> TypeGuard[Callable]:
+def is_func_sync_generator(func: object) -> TypeIs[Callable]:
     '''
     :data:`True` only if the passed object is an **synchronous generator
     factory** (i.e., awaitable callable containing one or more ``yield``
@@ -809,7 +908,7 @@ def is_func_nested(func: Callable) -> bool:
     )
 
 # ....................{ TESTERS ~ nested : closure         }....................
-def is_func_closure(func: Any) -> TypeGuard[Callable]:
+def is_func_closure(func: Any) -> TypeIs[Callable]:
     '''
     :data:`True` only if the passed callable is a **closure** (i.e., nested
     callable accessing one or more variables declared by the parent callable
@@ -839,7 +938,7 @@ def is_func_closure(func: Any) -> TypeGuard[Callable]:
     return getattr(func, '__closure__', None) is not None
 
 # ....................{ TESTERS ~ wrapper                  }....................
-def is_func_wrapper(func: Any) -> TypeGuard[Callable]:
+def is_func_wrapper(func: Any) -> TypeIs[Callable]:
     '''
     :data:`True` only if the passed object is a **callable wrapper** (i.e.,
     callable decorated by the standard :func:`functools.wraps` decorator for
@@ -880,7 +979,7 @@ def is_func_wrapper_isomorphic(
 
     # Optional parameters.
     wrapper: Optional[Callable] = None,
-) -> TypeGuard[Callable]:
+) -> TypeIs[Callable]:
     '''
     :data:`True` only if the passed object is an **isomorphic wrapper** (i.e.,
     callable decorated by the standard :func:`functools.wraps` decorator for
