@@ -11,7 +11,6 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from abc import abstractmethod
-from beartype.roar import BeartypeDecorHintPep544Exception
 from beartype.typing import (
     Any,
     BinaryIO,
@@ -20,12 +19,37 @@ from beartype.typing import (
     Optional,
     TextIO,
 )
+from beartype._data.api.standard.datamodtyping import TYPING_MODULE_NAMES
 from beartype._data.cls.datacls import TYPES_PEP484_GENERIC_IO
+from beartype._data.hint.datahintpep import (
+    Hint,
+    TypeIs,
+)
 from beartype._util.cls.utilclstest import is_type_builtin_or_fake
 from typing import Protocol as typing_Protocol  # <-- unoptimized protocol
 
+# ....................{ MAPPINGS                           }....................
+# Initialized by the init_HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL() function.
+HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL: Dict[type, Any] = {}
+'''
+Dictionary mapping from each :mod:`typing` **IO generic base class** (i.e.,
+either :class:`typing.IO` itself *or* a subclass of :class:`typing.IO` defined
+by the :mod:`typing` module) to the associated :mod:`beartype` **IO protocol**
+(i.e., either :class:`_Pep544IO` itself *or* a subclass of :class:`_Pep544IO`
+defined by this submodule).
+'''
+
 # ....................{ TESTERS                            }....................
-def is_hint_pep484_generic_io(hint: object) -> bool:
+#FIXME: We'd strongly prefer to annotate this as returning
+#"TypeIs[typing_Protocol]" rather than "TypeIs[type]". The former is
+#considerably more fine-grained and thus broadly useful than the latter. Sadly,
+#both "mypy" and "pyright" complain about this. Both are wrong, of course:
+#    beartype/_util/hint/pep/proposal/pep544.py:43: error: Variable
+#    "typing.Protocol" is not valid as a type  [valid-type]
+#
+#Nonsense! "typing.Protocol" is *LITERALLY* a type. It's a type, guys. Like most
+#types, it's both a type hint *AND* a type. That's fine. Oh, well.
+def is_hint_pep484_generic_io(hint: Hint) -> TypeIs[type]:
     '''
     :data:`True` only if the passed object is a functionally useless
     :pep:`484`-compliant :mod:`typing` **IO generic superclass** (i.e., either
@@ -79,7 +103,9 @@ def is_hint_pep484_generic_io(hint: object) -> bool:
     return hint_origin in TYPES_PEP484_GENERIC_IO
 
 
-def is_hint_pep544_protocol(hint: object) -> bool:
+#FIXME: We'd strongly prefer to annotate this as returning
+#"TypeIs[typing_Protocol]" rather than "TypeIs[type]". See above for commentary.
+def is_hint_pep544_protocol(hint: Hint) -> TypeIs[type]:
     '''
     :data:`True` only if the passed object is a :pep:`544`-compliant
     **protocol** (i.e., subclass of the :class:`typing.Protocol` superclass).
@@ -123,189 +149,44 @@ def is_hint_pep544_protocol(hint: object) -> bool:
         not is_type_builtin_or_fake(hint)  # pyright: ignore
     )
 
-# ....................{ REDUCERS                           }....................
-def reduce_hint_pep484_generic_io_to_pep544_protocol(
-    hint: Any, exception_prefix: str) -> Any:
-    '''
-    :pep:`544`-compliant :mod:`beartype` **IO protocol** (i.e., either
-    :class:`._Pep544IO` itself *or* a subclass of that class defined by this
-    submodule intentionally designed to be usable at runtime) corresponding to
-    the passed :pep:`484`-compliant :mod:`typing` **IO generic base class**
-    (i.e., either :class:`typing.IO` itself *or* a subclass of
-    :class:`typing.IO` defined by the :mod:`typing` module effectively unusable
-    at runtime due to botched implementation details).
 
-    This reducer is intentionally *not* memoized (e.g., by the
+#FIXME: Unit test us up, please.
+def is_hint_pep544_protocol_supertype(hint: Hint) -> TypeIs[type]:
+    '''
+    :data:`True` only if the passed object is a :pep:`544`-compliant
+    **protocol superclass** (i.e., either the :class:`typing.Protocol`,
+    :class:`typing_extensions.Protocol`, or :class:`beartype.typing.Protocol`
+    superclass).
+
+    This tester is intentionally *not* memoized (e.g., by the
     :func:`callable_cached` decorator), as the implementation trivially reduces
-    to an efficient one-liner thanks to caching internally performed by this
-    reducer.
+    to an efficient one-liner.
 
     Parameters
     ----------
-    hint : type
-        :pep:`484`-compliant :mod:`typing` IO generic base class to be replaced
-        by the corresponding :pep:`544`-compliant :mod:`beartype` IO protocol.
-    exception_prefix : str
-        Human-readable label prefixing the representation of this object in the
-        exception message.
+    hint : object
+        Object to be inspected.
 
     Returns
     -------
-    Protocol
-        :pep:`544`-compliant :mod:`beartype` IO protocol corresponding to this
-        :pep:`484`-compliant :mod:`typing` IO generic base class.
-
-    Raises
-    ------
-    BeartypeDecorHintPep544Exception
-        If this object is *not* a :pep:`484`-compliant IO generic base class.
+    bool
+        :data:`True` only if this object is a :pep:`544`-compliant protocol
+        superclass.
     '''
 
-    # If this object is *NOT* a PEP 484-compliant "typing" IO generic,
-    # raise an exception.
-    if not is_hint_pep484_generic_io(hint):
-        raise BeartypeDecorHintPep544Exception(
-            f'{exception_prefix}type hint {repr(hint)} not '
-            f'PEP 484 IO generic base class '
-            f'(i.e., "typing.IO", "typing.BinaryIO", or "typing.TextIO").'
-        )
-    # Else, this object is *NOT* a PEP 484-compliant "typing" IO generic.
-    #
-    # If this dictionary has yet to be initialized, this submodule has yet to be
-    # initialized. In this case, do so.
-    #
-    # Note that this initialization is intentionally deferred until required.
-    # Why? Because this initialization performs somewhat space- and
-    # time-intensive work -- including importation of the "beartype.vale"
-    # subpackage, which we strictly prohibit importing from global scope.
-    elif not _HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL:
-        _init()
-    # In any case, this dictionary is now initialized.
+    # Return true only if...
+    return (
+        # This object is a type *AND*...
+        isinstance(hint, type) and
+        # The unqualified basename of this type is that of *ALL* protocol
+        # superclasses *AND*...
+        hint.__name__ == 'Protocol' and
+        # A typing-like module declares this type.
+        hint.__module__ in TYPING_MODULE_NAMES
+    )
 
-    # PEP 544-compliant IO protocol implementing this PEP 484-compliant IO
-    # generic if any *OR* "None" otherwise.
-    pep544_protocol = _HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL.get(hint)
-
-    # If *NO* PEP 544-compliant IO protocol implements this generic...
-    if pep544_protocol is None:
-        # Avoid circular import dependencies.
-        from beartype._util.hint.pep.utilpepget import (
-            get_hint_pep_origin_or_none,
-            get_hint_pep_typevars,
-        )
-
-        # Tuple of zero or more type variables parametrizing this hint.
-        hint_typevars = get_hint_pep_typevars(hint)
-
-        #FIXME: Unit test us up, please.
-        # If this hint is unparametrized, raise an exception.
-        if not hint_typevars:
-            raise BeartypeDecorHintPep544Exception(
-                f'{exception_prefix}PEP 484 IO generic base class '
-                f'{repr(hint)} invalid (i.e., not subscripted (indexed) by '
-                f'either "str", "bytes", "typing.Any", or "typing.AnyStr").'
-            )
-        # Else, this hint is parametrized and thus defines the "__origin__"
-        # dunder attribute whose value is the type originating this hint.
-
-        #FIXME: Attempt to actually handle this type variable, please.
-        # Reduce this parametrized hint (e.g., "typing.IO[typing.AnyStr]") to
-        # the equivalent unparametrized hint (e.g., "typing.IO"), effectively
-        # ignoring the type variable parametrizing this hint.
-        hint_unparametrized: type = get_hint_pep_origin_or_none(hint)  # type: ignore[assignment]
-
-        # PEP 544-compliant IO protocol implementing this unparametrized PEP
-        # 484-compliant IO generic. For efficiency, we additionally cache this
-        # mapping under the original parametrized hint to minimize the cost of
-        # similar reductions under subsequent annotations.
-        pep544_protocol = \
-            _HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL[hint] = \
-            _HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL[hint_unparametrized]
-    # Else, some PEP 544-compliant IO protocol implements this generic.
-
-    # Return this protocol.
-    return pep544_protocol
-
-# ....................{ PRIVATE ~ mappings                 }....................
-# Conditionally initialized by the _init() function below.
-_HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL: Dict[type, Any] = {}
-'''
-Dictionary mapping from each :mod:`typing` **IO generic base class** (i.e.,
-either :class:`typing.IO` itself *or* a subclass of :class:`typing.IO` defined
-by the :mod:`typing` module) to the associated :mod:`beartype` **IO protocol**
-(i.e., either :class:`_Pep544IO` itself *or* a subclass of :class:`_Pep544IO`
-defined by this submodule).
-'''
-
-# ....................{ PRIVATE ~ classes                  }....................
-# Conditionally initialized by the _init() function below.
-_Pep544IO: Any = None  # type: ignore[assignment]
-'''
-:pep:`544`-compliant protocol base class for :class:`_Pep544TextIO` and
-:class:`_Pep544BinaryIO`.
-
-This is an abstract, generic version of the return of open().
-
-NOTE: This does not distinguish between the different possible classes (text
-vs. binary, read vs. write vs. read/write, append-only, unbuffered). The TextIO
-and BinaryIO subclasses below capture the distinctions between text vs. binary,
-which is pervasive in the interface; however we currently do not offer a way to
-track the other distinctions in the type system.
-
-Design
-------
-This base class intentionally duplicates the contents of the existing
-:class:`typing.IO` generic base class by substituting the useless
-:class:`typing.Generic` superclass of the latter with the useful
-:class:`typing.Protocol` superclass of the former. Why? Because *no* stdlib
-classes excluding those defined by the :mod:`typing` module itself subclass
-:class:`typing.IO`. However, :class:`typing.IO` leverages neither the
-:class:`abc.ABCMeta` metaclass *nor* the :class:`typing.Protocol` superclass
-needed to support structural subtyping. Therefore, *no* stdlib objects
-(including those returned by the :func:`open` builtin) satisfy either
-:class:`typing.IO` itself or any subclasses of :class:`typing.IO` (e.g.,
-:class:`typing.BinaryIO`, :class:`typing.TextIO`). Therefore,
-:class:`typing.IO` and all subclasses thereof are functionally useless for all
-practical intents. The conventional excuse `given by Python maintainers to
-justify this abhorrent nonsensicality is as follows <typeshed_>`__:
-
-    There are a lot of "file-like" classes, and the typing IO classes are meant
-    as "protocols" for general files, but they cannot actually be protocols
-    because the file protocol isn't very well defined—there are lots of methods
-    that exist on some but not all filelike classes.
-
-Like most :mod:`typing`-oriented confabulation, that, of course, is bollocks.
-Refactoring the family of :mod:`typing` IO classes from inveterate generics
-into pragmatic protocols is both technically trivial and semantically useful,
-because that is exactly what :mod:`beartype` does. It works. It necessitates
-modifying three lines of existing code. It preserves backward compatibility. In
-short, it should have been done a decade ago. If the file protocol "isn't very
-well defined," the solution is to define that protocol with a rigorous type
-hierarchy satisfying all possible edge cases. The solution is *not* to pretend
-that no solutions exist, that the existing non-solution suffices, and instead
-do nothing. Welcome to :mod:`typing`, where no one cares that nothing works as
-advertised (or at all)... *and no one ever will.*
-
-.. _typeshed:
-   https://github.com/python/typeshed/issues/3225#issuecomment-529277448
-'''
-
-
-# Conditionally initialized by the _init() function below.
-_Pep544BinaryIO: Any = None  # type: ignore[assignment]
-'''
-Typed version of the return of :func:`open` in binary mode.
-'''
-
-
-# Conditionally initialized by the _init() function below.
-_Pep544TextIO: Any = None  # type: ignore[assignment]
-'''
-Typed version of the return of :func:`open` in text mode.
-'''
-
-# ....................{ INITIALIZERS                       }....................
-def _init() -> None:
+# ....................{ FACTORIES                          }....................
+def init_HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL() -> None:
     '''
     Initialize this submodule.
     '''
@@ -509,7 +390,7 @@ def _init() -> None:
     # reassigned to a new dictionary. Why? Because the higher-level
     # reduce_hint_pep484_generic_io_to_pep544_protocol() function calling this
     # lower-level initializer has already imported this global.
-    _HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL.update({
+    HINT_PEP484_IO_GENERIC_TO_PEP544_PROTOCOL.update({
         # Unsubscripted mappings.
         IO:        _Pep544IO,
         BinaryIO:  _Pep544BinaryIO,
@@ -541,3 +422,70 @@ def _init() -> None:
         IO[bytes]: _Pep544BinaryIO,
         IO[str]:   _Pep544TextIO,
     })
+
+# ....................{ PRIVATE ~ classes                  }....................
+# Conditionally initialized by the _init() function below.
+_Pep544IO: Any = None  # type: ignore[assignment]
+'''
+:pep:`544`-compliant protocol base class for :class:`_Pep544TextIO` and
+:class:`_Pep544BinaryIO`.
+
+This is an abstract, generic version of the return of open().
+
+NOTE: This does not distinguish between the different possible classes (text
+vs. binary, read vs. write vs. read/write, append-only, unbuffered). The TextIO
+and BinaryIO subclasses below capture the distinctions between text vs. binary,
+which is pervasive in the interface; however we currently do not offer a way to
+track the other distinctions in the type system.
+
+Design
+------
+This base class intentionally duplicates the contents of the existing
+:class:`typing.IO` generic base class by substituting the useless
+:class:`typing.Generic` superclass of the latter with the useful
+:class:`typing.Protocol` superclass of the former. Why? Because *no* stdlib
+classes excluding those defined by the :mod:`typing` module itself subclass
+:class:`typing.IO`. However, :class:`typing.IO` leverages neither the
+:class:`abc.ABCMeta` metaclass *nor* the :class:`typing.Protocol` superclass
+needed to support structural subtyping. Therefore, *no* stdlib objects
+(including those returned by the :func:`open` builtin) satisfy either
+:class:`typing.IO` itself or any subclasses of :class:`typing.IO` (e.g.,
+:class:`typing.BinaryIO`, :class:`typing.TextIO`). Therefore,
+:class:`typing.IO` and all subclasses thereof are functionally useless for all
+practical intents. The conventional excuse `given by Python maintainers to
+justify this abhorrent nonsensicality is as follows <typeshed_>`__:
+
+    There are a lot of "file-like" classes, and the typing IO classes are meant
+    as "protocols" for general files, but they cannot actually be protocols
+    because the file protocol isn't very well defined—there are lots of methods
+    that exist on some but not all filelike classes.
+
+Like most :mod:`typing`-oriented confabulation, that, of course, is bollocks.
+Refactoring the family of :mod:`typing` IO classes from inveterate generics
+into pragmatic protocols is both technically trivial and semantically useful,
+because that is exactly what :mod:`beartype` does. It works. It necessitates
+modifying three lines of existing code. It preserves backward compatibility. In
+short, it should have been done a decade ago. If the file protocol "isn't very
+well defined," the solution is to define that protocol with a rigorous type
+hierarchy satisfying all possible edge cases. The solution is *not* to pretend
+that no solutions exist, that the existing non-solution suffices, and instead
+do nothing. Welcome to :mod:`typing`, where no one cares that nothing works as
+advertised (or at all)... *and no one ever will.*
+
+.. _typeshed:
+   https://github.com/python/typeshed/issues/3225#issuecomment-529277448
+'''
+
+
+# Conditionally initialized by the _init() function below.
+_Pep544BinaryIO: Any = None  # type: ignore[assignment]
+'''
+Typed version of the return of :func:`open` in binary mode.
+'''
+
+
+# Conditionally initialized by the _init() function below.
+_Pep544TextIO: Any = None  # type: ignore[assignment]
+'''
+Typed version of the return of :func:`open` in text mode.
+'''
