@@ -14,6 +14,7 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                            }....................
 from beartype.meta import URL_ISSUES
 from beartype.roar import BeartypeDecorHintNonpepException
+from beartype.typing import NoReturn
 from beartype._data.hint.datahintpep import Hint
 from beartype._data.hint.datahinttyping import TypeException
 from beartype._util.cache.utilcachecall import callable_cached
@@ -28,7 +29,7 @@ from beartype._util.hint.pep.utilpeptest import (
     is_hint_pep_supported,
 )
 from beartype._util.hint.pep.proposal.pep585 import (
-    is_hint_pep585_builtin_subscripted)
+    is_hint_pep585_builtin_subbed)
 from beartype._util.hint.pep.proposal.pep484604 import is_hint_pep604
 
 # ....................{ RAISERS                            }....................
@@ -116,7 +117,7 @@ def die_as_hint_unsupported(
     # Optional parameters.
     exception_cls: TypeException = BeartypeDecorHintNonpepException,
     exception_prefix: str = '',
-) -> None:
+) -> NoReturn:
     '''
     Unconditionally raise an exception describing the failure of the passed
     object to be a **supported type hint** (i.e., object supported by the
@@ -309,7 +310,7 @@ def is_hint_cacheworthy(hint: Hint) -> bool:
             # Note that this additionally includes all third-party type hints
             # that derive from the "types.GenericAlias" superclass, including:
             # * "numpy.typing.NDArray[...]" type hints.
-            is_hint_pep585_builtin_subscripted(hint) or
+            is_hint_pep585_builtin_subbed(hint) or
             # PEP 604-compliant (e.g., "int | str"). This hint is *NOT*
             # self-caching (e.g., "int | str is not int | str").
             #
