@@ -23,7 +23,7 @@ from beartype.typing import (
     Optional,
 )
 from beartype._cave._cavemap import NoneTypeOr
-from beartype._conf.confcls import BeartypeConf
+from beartype._conf.confmain import BeartypeConf
 from beartype._data.hint.datahinttyping import CollectionStrs
 from collections.abc import (
     Collection as CollectionABC,
