@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -58,20 +58,15 @@ standard :mod:`collections.abc` protocols).
 # ....................{ IMPORTS                            }....................
 from beartype.typing import (
     TYPE_CHECKING,
+    Annotated,
     Dict,
     Optional,
     Set,
 )
-from beartype._data.kind.datakinddict import DICT_EMPTY
-from beartype._data.hint.datahinttyping import (
-    FrozenSetStrs,
-)
-from beartype._util.api.utilapityping import import_typing_attr_or_none
+from beartype._data.kind.datakindmap import FROZENDICT_EMPTY
+from beartype._data.hint.datahinttyping import FrozenSetStrs
 from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.hint.pep.utilpepget import get_hint_pep_origin_type
-from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
-from beartype._util.utilobjectattr import (
-    get_object_methods_name_to_value_explicit)
+from beartype._util.utilobjattr import get_object_methods_name_to_value_explicit
 from collections.abc import (
     Collection as CollectionABC,
 )
@@ -146,29 +141,21 @@ def infer_hint_collections_abc(obj: object, **kwargs) -> Optional[object]:
 
     # If at least one "collections.abc" protocol validates this type...
     if hint_factory:
+        # Defer heavyweight imports.
+        from beartype.vale import IsInstance
+
         # If this object is a collection...
         if isinstance(obj, CollectionABC):
             # Avoid circular import dependencies.
             from beartype.door._func.infer.collection.infercollectionitems import (
                 infer_hint_collection_items)
 
-            # "collections.abc" protocol validating this type, defined as
-            # either...
-            origin_type: type = (
-                # If the active Python interpreter targets Python >= 3.9 and
-                # thus supports PEP 585, this hint factory as is. Why? Because
-                # this hint factory is already its own origin type due to being
-                # a valid "collections.abc" superclass;
-                hint_factory  # type: ignore[assignment]
-                if IS_PYTHON_AT_LEAST_3_9 else
-                # Else, the active Python interpreter targets Python < 3.9 and
-                # thus fails to support PEP 585. In this case, the origin type
-                # underlying this hint factory (e.g., "collections.abc.Mapping"
-                # for the hint factory "typing.Mapping").
-                get_hint_pep_origin_type(hint_factory)
-            )
-
+            # "collections.abc" protocol validating this type, defined this hint
+            # factory itself. Why? Because this hint factory is already its own
+            # origin type due to being a valid "collections.abc" superclass.
+            origin_type: type = hint_factory  # type: ignore[assignment]
             # print(f'Inferring iterable {repr(obj_type_collections_abc)} subscription...')
+
             # Hint recursively validating this iterable (including *ALL* items
             # transitively reachable from this iterable), defined by
             # subscripting this "collections.abc" protocol by the union of the
@@ -198,30 +185,19 @@ def infer_hint_collections_abc(obj: object, **kwargs) -> Optional[object]:
         #  full-blown PEP 593-compliant "Annotated[...]" parent type hint
         #  encapsulating this "hint" as a child type hint.
 
-        # PEP 593-compliant "Annotated" type hint factory imported from either
-        # the standard "typing" or third-party "typing_extensions" modules if
-        # importable from at least one of those modules *OR* "None" otherwise.
-        Annotated = import_typing_attr_or_none('Annotated')
-
-        # If "typing(|_extensions).Annotated" is importable...
-        if Annotated is not None:
-            # Defer heavyweight imports.
-            from beartype.vale import IsInstance
-
-            # Generalize this possibly subscripted "collections.abc" protocol
-            # into a PEP 593-compliant "Annotated[...]" hint annotating this
-            # protocol to additionally require that arbitrary objects satisfying
-            # this hint also be instances of the same type as the passed object.
-            #
-            # Doing so avoids false positives, as the original "hint" (i.e.,
-            # possibly subscripted "collections.abc" protocol) widely matches
-            # *ANY* object of *ANY* type that simply satisfies that protocol.
-            # However, the type of the passed object (probably) encapsulates
-            # other attributes and behaviours *NOT* described by this protocol.
-            # In and of itself, this protocol fails to fully validate other
-            # objects of the same type.
-            hint = Annotated[hint, IsInstance[obj_type]]
-        # Else, "typing(|_extensions).Annotated" is unimportable.
+        # Generalize this possibly subscripted "collections.abc" protocol
+        # into a PEP 593-compliant "Annotated[...]" hint annotating this
+        # protocol to additionally require that arbitrary objects satisfying
+        # this hint also be instances of the same type as the passed object.
+        #
+        # Doing so avoids false positives, as the original "hint" (i.e.,
+        # possibly subscripted "collections.abc" protocol) widely matches
+        # *ANY* object of *ANY* type that simply satisfies that protocol.
+        # However, the type of the passed object (probably) encapsulates
+        # other attributes and behaviours *NOT* described by this protocol.
+        # In and of itself, this protocol fails to fully validate other
+        # objects of the same type.
+        hint = Annotated[hint, IsInstance[obj_type]]
     # Else, *NO* "collections.abc" protocol validates this type. In this
     # case, fallback to returning "None".
 
@@ -516,7 +492,7 @@ class _FiniteStateMachineNode(object):
 
         # Optional parameters.
         hint_factory: object = None,
-        nodes_next: _FiniteStateMachine = DICT_EMPTY,
+        nodes_next: _FiniteStateMachine = FROZENDICT_EMPTY,
     ) -> None:
         '''
 
