@@ -391,11 +391,9 @@ def test_door_typehint_is_ignorable(hints_pep_meta, hints_ignorable) -> None:
     # Defer test-specific imports.
     from beartype.door import TypeHint
     from beartype.roar import BeartypeDoorException, BeartypeDoorNonpepException
-    from beartype.typing import (
-        Any,
-        TypeVar,
-    )
-    from beartype._check.convert.convsanify import sanify_hint_child
+    from beartype.typing import TypeVar
+    from beartype._check.convert.convsanify import sanify_hint_any
+    from beartype._check.metadata.hint.hintsane import HINT_SANE_IGNORABLE
     from beartype._util.hint.pep.proposal.pep484.pep484typevar import (
         get_hint_pep484_typevar_bound_or_none)
     from contextlib import suppress
@@ -441,7 +439,7 @@ def test_door_typehint_is_ignorable(hints_pep_meta, hints_ignorable) -> None:
                 hint_typevar_bound is None or
                 # This type hint is constrained by one or more ignorable
                 # constraints.
-                sanify_hint_child(hint_typevar_bound) is Any
+                sanify_hint_any(hint=hint_typevar_bound) is HINT_SANE_IGNORABLE
             )
         # Else, this hint is *NOT* a type variable.
 
