@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -35,18 +35,16 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
     from beartype._data.hint.datahinttyping import T
     from beartype._data.hint.pep.sign.datapepsigns import (
         HintSignBinaryIO,
-        HintSignGeneric,
-        HintSignIO,
+        HintSignPep484585GenericSubscripted,
+        HintSignPep484585GenericUnsubscripted,
         HintSignTextIO,
     )
-    from beartype._util.api.utilapityping import get_typing_attrs
+    from beartype._util.api.standard.utiltyping import get_typing_attrs
     from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
         HintPepMetadata,
         HintPithSatisfiedMetadata,
         HintPithUnsatisfiedMetadata,
     )
-    from beartype_test._util.module.pytmodtest import (
-        is_package_beartype_vale_usable)
     from pathlib import Path
 
     # ..................{ LOCALS                             }..................
@@ -80,24 +78,17 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
     # interpreter and thus *CANNOT* be defined as a standard tuple.
     binaryio_piths_meta = [
         # Open read-only binary file handle to this submodule.
-        HintPithSatisfiedMetadata(
-            pith=open_file_binary, is_pith_factory=True),
+        HintPithSatisfiedMetadata(pith=open_file_binary, is_pith_factory=True),
         # Bytestring constant.
-        HintPithUnsatisfiedMetadata(
-            b"Of a thieved imagination's reveries"),
-    ]
-
-    # If beartype validators are usable under the active Python interpreter...
-    if is_package_beartype_vale_usable():
-        # Add a "HintPithUnsatisfiedMetadata" instance validating open
+        HintPithUnsatisfiedMetadata(b"Of a thieved imagination's reveries"),
+        # "HintPithUnsatisfiedMetadata" instance validating open
         # read-only text file handles to violate both "typing.BinaryIO" *AND*
         # "typing.IO[bytes]" type hints. This validation requires beartype
         # validators, as the only means of differentiating objects satisfying
         # the "typing.BinaryIO" protocol from those satisfying the "typing.IO"
         # protocol is with an inverted instance check. Cue beartype validators.
-        binaryio_piths_meta.append(
-            HintPithUnsatisfiedMetadata(
-                pith=open_file_text, is_pith_factory=True))
+        HintPithUnsatisfiedMetadata(pith=open_file_text, is_pith_factory=True),
+    ]
 
     # ..................{ PROTOCOLS ~ structural             }..................
     class ProtocolCustomStructural(object):
@@ -112,8 +103,6 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
         def omega(self) -> str:
             return 'Surfeit need'
 
-    # Instance of this class.
-    protocol_custom_structural = ProtocolCustomStructural()
 
     class ProtocolSupportsInt(object):
         '''
@@ -131,6 +120,9 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
         def __int__(self) -> int:
             return 42
 
+    # Instance of the custom protocol defined above.
+    protocol_custom_structural = ProtocolCustomStructural()
+
     # ..................{ FACTORIES ~ Protocol               }..................
     # For each PEP-specific type hint factory importable from each currently
     # importable "typing" module...
@@ -139,7 +131,7 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
         @runtime_checkable
         class ProtocolCustomUntypevared(Protocol):
             '''
-            User-defined protocol parametrized by *NO* type variables declaring
+            User-defined protocol parametrized by *no* type variables declaring
             arbitrary concrete and abstract methods.
             '''
 
@@ -219,7 +211,7 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # User-defined protocol parametrized by *NO* type variables.
             HintPepMetadata(
                 hint=ProtocolCustomUntypevared,
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=ProtocolCustomUntypevared,
                 is_type_typing=False,
                 piths_meta=(
@@ -233,10 +225,10 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # User-defined protocol parametrized by a type variable.
             HintPepMetadata(
                 hint=ProtocolCustomTypevared,
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=ProtocolCustomTypevared,
-                is_typevars=True,
                 is_type_typing=False,
+                typevars=(T,),
                 piths_meta=(
                     # Unrelated object satisfying this protocol.
                     HintPithSatisfiedMetadata(protocol_custom_structural),
@@ -249,9 +241,9 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # parametrized by the same type variables in the same order.
             HintPepMetadata(
                 hint=ProtocolCustomTypevared[T],
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericSubscripted,
                 generic_type=ProtocolCustomTypevared,
-                is_typevars=True,
+                typevars=(T,),
                 is_typing=False,
                 piths_meta=(
                     # Unrelated object satisfying this protocol.
@@ -266,7 +258,7 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # parametrized by a concrete type satisfying this type variable.
             HintPepMetadata(
                 hint=ProtocolCustomTypevared[str],
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericSubscripted,
                 generic_type=ProtocolCustomTypevared,
                 is_typing=False,
                 piths_meta=(
@@ -281,7 +273,7 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # User-defined abstract protocol subclassing the ABC superclass.
             HintPepMetadata(
                 hint=ProtocolCustomABC,
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=ProtocolCustomABC,
                 is_type_typing=False,
                 piths_meta=(
@@ -343,9 +335,9 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # Unsubscripted "IO" abstract base class (ABC).
             HintPepMetadata(
                 hint=IO,
-                pep_sign=HintSignIO,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=IO,
-                is_typevars=True,
+                typevars=(AnyStr,),
                 piths_meta=(
                     # Open read-only text file handle to this submodule.
                     HintPithSatisfiedMetadata(
@@ -363,7 +355,7 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # All possible subscriptions of the "IO" abstract base class (ABC).
             HintPepMetadata(
                 hint=IO[Any],
-                pep_sign=HintSignIO,
+                pep_sign=HintSignPep484585GenericSubscripted,
                 generic_type=IO,
                 piths_meta=(
                     # Open read-only binary file handle to this submodule.
@@ -379,13 +371,13 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             ),
             HintPepMetadata(
                 hint=IO[bytes],
-                pep_sign=HintSignIO,
+                pep_sign=HintSignPep484585GenericSubscripted,
                 generic_type=IO,
                 piths_meta=binaryio_piths_meta,
             ),
             HintPepMetadata(
                 hint=IO[str],
-                pep_sign=HintSignIO,
+                pep_sign=HintSignPep484585GenericSubscripted,
                 generic_type=IO,
                 piths_meta=(
                     # Open read-only text file handle to this submodule.
@@ -405,9 +397,9 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # Parametrization of the "IO" abstract base class (ABC).
             HintPepMetadata(
                 hint=IO[AnyStr],
-                pep_sign=HintSignIO,
+                pep_sign=HintSignPep484585GenericSubscripted,
                 generic_type=IO,
-                is_typevars=True,
+                typevars=(AnyStr,),
                 piths_meta=(
                     # Open read-only binary file handle to this submodule.
                     HintPithSatisfiedMetadata(
@@ -430,10 +422,14 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # Unsubscripted "SupportsAbs" abstract base class (ABC).
             HintPepMetadata(
                 hint=SupportsAbs,
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=SupportsAbs,
                 # Oddly, some but *NOT* all "typing.Supports*" ABCs are
-                # parametrized by type variables. *shrug*
+                # parametrized by type variables. However, these type variables
+                # have nondescript names (e.g., "T") *NOT* officially exported
+                # as public global variables by the "typing" module. To reduce
+                # the likelihood of unexpected breakage under future Python
+                # versions, we avoid asserting these exact type variables.
                 is_typevars=True,
                 piths_meta=(
                     # Integer constant.
@@ -453,7 +449,7 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # Unsubscripted "SupportsBytes" abstract base class (ABC).
             HintPepMetadata(
                 hint=SupportsBytes,
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=SupportsBytes,
                 piths_meta=(
                     # Platform-agnostic filesystem path object constant.
@@ -500,7 +496,7 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # Unsubscripted "SupportsFloat" abstract base class (ABC).
             HintPepMetadata(
                 hint=SupportsFloat,
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=SupportsFloat,
                 piths_meta=(
                     # Integer constant.
@@ -521,7 +517,7 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # introduced by Python 3.8.0.
             HintPepMetadata(
                 hint=SupportsIndex,
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=SupportsIndex,
                 piths_meta=(
                     # Integer constant.
@@ -541,7 +537,7 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # Unsubscripted "SupportsInt" abstract base class (ABC).
             HintPepMetadata(
                 hint=SupportsInt,
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=SupportsInt,
                 piths_meta=(
                     # Floating-point number constant.
@@ -564,10 +560,10 @@ def hints_pep544_meta() -> 'List[HintPepMetadata]':
             # Unsubscripted "SupportsRound" abstract base class (ABC).
             HintPepMetadata(
                 hint=SupportsRound,
-                pep_sign=HintSignGeneric,
+                pep_sign=HintSignPep484585GenericUnsubscripted,
                 generic_type=SupportsRound,
                 # Oddly, some but *NOT* all "typing.Supports*" ABCs are
-                # parametrized by type variables. *shrug*
+                # parametrized by type variables. See "SupportsAbs" above.
                 is_typevars=True,
                 piths_meta=(
                     # Floating-point number constant.
@@ -591,7 +587,7 @@ def hints_pep544_ignorable_shallow() -> list:
     '''
 
     # ..................{ IMPORTS                            }..................
-    from beartype._util.api.utilapityping import get_typing_attrs
+    from beartype._util.api.standard.utiltyping import get_typing_attrs
 
     # ..................{ LOCALS                             }..................
     # List of all PEP-specific shallowly ignorable type hints to be returned.
@@ -630,8 +626,11 @@ def hints_pep544_ignorable_deep() -> list:
     '''
 
     # ..................{ IMPORTS                            }..................
-    from beartype._util.api.utilapityping import get_typing_attrs
-    from beartype._data.hint.datahinttyping import S, T
+    from beartype._util.api.standard.utiltyping import get_typing_attrs
+    from beartype._data.hint.datahinttyping import (
+        S,
+        T,
+    )
 
     # ..................{ LOCALS                             }..................
     # List of all PEP-specific deeply ignorable type hints to be returned.
